#!/usr/bin/env node

// require modules
var fs			= require('fs');
var path		= require('path');
var formideCLI	= require('commander');
var colors		= require('colors');

// define global variable to reach all lib items
lib = {
	settings: 	require('./lib/settings'),
	auth: 		require('./lib/auth'),
	api: 		require('./lib/api'),
	project:	require('./lib/project')
};

// load formide-cli package.json
var formideCliJson = require( path.join(__dirname, 'package.json') );

// set formideCLI version
formideCLI.version(formideCliJson.version);

// set available commands
formideCLI
	.command('login')
	.description('Login to your FORMIDE account')
	.action(lib.auth.login);

formideCLI
	.command('logout')
	.description('Logout of your FORMIDE account')
	.action(lib.auth.logout);

formideCLI
	.command('me')
	.description('Get currently logged in user')
	.action(lib.auth.me);

formideCLI
	.command('init [path]')
	.description('Start a new FORMIDE app from template')
	.action(lib.project.create);
	
formideCLI
	.command('run')
	.description('Run project in current directory locally')
	.action(lib.project.run);

formideCLI
	.command('publish')
	.description('Publish project to FORMIDE app store')
	.action(lib.project.publish);

formideCLI
	.command('info')
	.description('Get info about the current project')
	.action(lib.project.info);

// parse command line arguments
formideCLI.parse(process.argv);

// show error when incorrect entry
if(!process.argv.slice(2).length) {
	program.outputHelp();
}